
Create Settings screen with various controls such as Switch, Button Groups. Also forces you to review useState

Keypoints:
- View does not support onPress
- But you can use a TouchableOpacity to group icon and text you want to have interaction (default react-native)

Mimic:
![](lAAqhWd.png)


Install expo react with starter boilerplate native-react-native-elements

Gear/Settings icon on the right. Include links to Icon and what icon font.

Have CHECKBOX for these options and make sure it has a background taking up entire width (Default react-native)
- Dark Mode
- Do Not Disturb
- Keep Awake
- Screen Saver
- Lock Keyboard
- Lock Screen

Clicking Dark Mode on and off will change StatusBar (Default react-native) which changes the top status bar’s color. Can only be tested in Android and iOS
https://reactnative.dev/docs/statusbar

The checkboxes should be all in a ScrollView at height 338px.

Have a SWITCH to “Save to all devices” spaced apart from all other controls and make sure it’s visually smaller width:
https://docs.expo.dev/ui-programming/implementing-a-checkbox/

ButtonGroup (react-native-elements)
https://reactnativeelements.com/docs/components/buttongroup

```
<ButtonGroup onPress={(selectedIndex) => console.log('Selected index:', selectedIndex)} buttons={buttons} containerStyle={styles.buttonGroup} />
```

Buttons for hardware locking (Lock Keyboard, Lock Screen)
Button for power management (Keep Awake, Screen Saver)
Button for digital wellness (Dark Mode, Do Not Disturb)

---

**Given up or comparing after you finished?** 

Answer how to install:
```
npx create-expo APP --example with-react-native-elements  
npm install react-native-safe-area-context
```

Answer:
```
import React, { useState } from 'react';  
import { StyleSheet, StatusBar, ScrollView, View, Text, Switch, TouchableOpacity  } from 'react-native';  
import { Header, Icon, CheckBox, ButtonGroup } from 'react-native-elements';  
import { SafeAreaProvider, SafeAreaView } from 'react-native-safe-area-context';  
  
export default function App() {  
  const [checked, setChecked] = useState({  
    darkMode: false,  
    DnD: false,  
    keepAwake: false,  
    screenSaver: false,  
    lockKeyboard: false,  
    lockScreen: false,  
    saveAll: true  
  });  
  const [filter, setFilter] = useState({  
    health: true,  
    power: true,  
    lock: true  
  })  
  
  const onLayoutRootView = () => {  
    // Your layout handling code here  
  };  
  
  return (  
    <SafeAreaProvider>  
    <SafeAreaView style={{ flex: 1 }}>  
      <StatusBar barStyle={checked.darkMode ? 'dark-content' : 'light-content'} />  
      <Header  
        centerComponent={{ text: 'Settings', style: { color: '#fff', fontSize: 18 } }}  
        rightComponent={<Icon name="settings" color="#fff" />}  
      />  
      <View style={styles.container} onLayout={onLayoutRootView}>  
        <View style={styles.fScreen}>  
          <ScrollView style={{height:"338px"}}>  
            {filter.health &&  
              (  
                <>  
                <CheckBox  
                title="Dark Mode"  
                checked={checked.darkMode}  
                onPress={ () => setChecked({  
                      ...checked,   
                      darkMode:!checked.darkMode  
                }) }  
                containerStyle={styles.row}  
              />  
              <CheckBox  
                title="Do Not Disturb"  
                checked={checked.DnD}  
                onPress={ () => setChecked({  
                      ...checked,   
                      DnD:!checked.DnD  
                }) }  
                containerStyle={styles.row}  
              />  
              </>  
              )  
            }  
            {filter.power &&  
              (  
              <>  
            <CheckBox  
              title="Keep Awake"  
              checked={checked.keepAwake}  
              onPress={ () => setChecked({  
                    ...checked,   
                    keepAwake:!checked.keepAwake  
              }) }  
              containerStyle={styles.row}  
            />  
            <CheckBox  
              title="Screen Saver"  
              checked={checked.screenSaver}  
              onPress={ () => setChecked({  
                    ...checked,   
                    screenSaver:!checked.screenSaver  
              }) }  
              containerStyle={styles.row}  
            />  
            </>  
              )  
            }  
  
            {filter.lock &&  
              (  
              <>  
            <CheckBox  
              title="Lock Keyboard"  
              checked={checked.lockKeyboard}  
              onPress={ () => setChecked({  
                    ...checked,   
                    lockKeyboard:!checked.lockKeyboard  
              }) }  
              containerStyle={styles.row}  
            />  
            <CheckBox  
              title="Lock Screen"  
              checked={checked.lockScreen}  
              onPress={ () => setChecked({  
                    ...checked,   
                    lockScreen:!checked.lockScreen  
              }) }  
              containerStyle={styles.row}  
            />  
            </>  
              )  
            }  
          </ScrollView>  
          <VertSpace/>
          <View style={styles.pullIn}>  
            <Switch  
              trackColor={{false: '#767577', true: '#81b0ff'}}  
              thumbColor={checked.saveAll ? 'rgb(0,0,170)' : 'white'}  
              ios_backgroundColor="#3e3e3e"  
              onValueChange={ () => setChecked({  
                ...checked,   
                saveAll:!checked.saveAll  
              }) }  
              value={checked.saveAll}  
            />  
            <Text style={{marginLeft:"10px", fontSize:"14px"}}>&nbsp;Save to all devices</Text>  
          </View>    
          <VertSpace/>
          <ButtonGroup onPress={(selectedIndex) => console.log('Selected index:', selectedIndex)} buttons={  
            [  
              <Button1 onPressPassthrough={ ()=>setFilter({ ...filter, lock:!filter.lock }) }/>,  
              <Button2 onPressPassthrough={ ()=>setFilter({ ...filter, power:!filter.power }) }/>,  
              <Button3 onPressPassthrough={ ()=>setFilter({ ...filter, health:!filter.health }) }/>,  
            ]  
          }/>  
            
        </View>  
      </View>  
    </SafeAreaView>  
    </SafeAreaProvider>  
  );  
}

const VertSpace = () => {
  return (<View style={{height:"20px", width:"1px"}}><Text></Text></View>)
}
  
const Button1 = ({onPressPassthrough}) => {  
  return (  
    <View><TouchableOpacity  style={styles.row} onPress={()=>{ onPressPassthrough() }}><Icon name="lock" color="#000" /><Text>Lock Hardware</Text></TouchableOpacity></View>  
  )  
}  
const Button2 = ({onPressPassthrough}) => {  
  return (  
    <View><TouchableOpacity  style={styles.row} onPress={()=>{ onPressPassthrough() }}><Icon name="bolt" color="#000" /><Text>Power Management</Text></TouchableOpacity></View>  
  )  
}  
const Button3 = ({onPressPassthrough}) => {  
  return (  
    <View><TouchableOpacity  style={styles.row} onPress={()=>{ onPressPassthrough() }}><Icon name="rowing" color="#000" /><Text>Digital Wellness</Text></TouchableOpacity></View>  
  )  
}  
  
const styles = StyleSheet.create({  
  container: {  
    flex: 1,  
    justifyContent: 'center',  
    alignItems: 'start',  
    alignContent: 'start'  
  },  
  pullIn: {  
    flexDirection: "row",  
    justifyContent: 'center',  
    alignContent: 'center',  
    alignItems: 'center'  
  },  
  row: {  
    flexDirection: 'row'  
  },  
  fScreen: {  
    width: "100%",  
    height: "100%"  
  }
});
```